pub struct ThrottleOpts {
pub leading: bool,
pub trailing: bool,
}Expand description
Options for throttle.
Fields
leading: boolEmit immediately at the leading edge of each window (default: true).
trailing: boolEmit the latest value at the trailing edge of each window (default: false).